@@ -7,7 +7,7 @@ def chunks(lst, n):
 
 
 class TaskMetadata():
-    def __init__(self, pk, rk, blob_name, params, offset, retry_count, batch_count, next_chunk, request, result, error, trace, state):
+    def __init__(self, pk, rk, blob_name, params, offset, retry_count, batch_count, next_batch, request, result, error, trace, state, total_batches):
         self.pk = pk
         self.rk = rk
         self.blob_name = blob_name
@@ -15,12 +15,13 @@ class TaskMetadata():
         self.offset = offset
         self.retry_count = retry_count
         self.batch_count = batch_count
-        self.next_batch = next_chunk
+        self.next_batch = next_batch
         self.request = request
         self.result = result
         self.error = error
         self.trace = trace
         self.state = state
+        self.total_batches = total_batches
 
     def get_base_entity(self):
         return { "PartitionKey": self.pk, "RowKey": self.rk }
@@ -37,17 +38,18 @@ class TaskMetadata():
             "StackTrace": self.trace,
             "RetryCount": self.retry_count,
             "Batch": self.batch_count,
-            "Offset": self.offset
+            "Offset": self.offset,
+            "TotalBatches": self.total_batches,
+            "NextBatch": self.next_batch
         }
-        if self.next_batch is not None:
-            row['NextChunk'] = json.dumps(self.next_batch, ensure_ascii=False)
         if self.params is not None:
             row['Params'] = json.dumps(self.params, ensure_ascii=False)
         return row
 
     @staticmethod
     def create_from_dict(row):
-        params, offset, retry_count, batch_count, next_chunk, request, blob_name = None, 0, 0, 0, None, None, None
+        params, offset, retry_count, batch_count, next_batch, request, blob_name = None, 0, 0, 0, None, None, None
+        total_batches = 0
         result, error, trace, state = None, None, None, None
         if 'BlobName' in row:
             blob_name = row['BlobName']
@@ -59,8 +61,8 @@ class TaskMetadata():
             retry_count = row['RetryCount']
         if 'Batch' in row:
             batch_count = row['Batch']
-        if 'NextChunk' in row and len(row['NextChunk']) > 0:
-            next_chunk = json.loads(row['NextChunk'])
+        if 'NextBatch' in row:
+            next_batch = row['NextBatch']
         if 'Request' in row:
             request = row['Request']
         if 'Result' in row:
@@ -71,9 +73,11 @@ class TaskMetadata():
             trace = row['StackTrace']
         if "State" in row:
             state = row["State"]
+        if "TotalBatches" in row:
+            total_batches = row["TotalBatches"]
         return TaskMetadata(
             row['PartitionKey'], row['RowKey'],
-            blob_name, params, offset, retry_count, batch_count, next_chunk, request, result, error, trace, state)
+            blob_name, params, offset, retry_count, batch_count, next_batch, request, result, error, trace, state, total_batches)
 
 
 class TaskResult:
