@@ -319,10 +319,9 @@ class Worker:
     def process_messages_from_queue(self, process_func, timeout=3600, sleep_timeout=1):
         while True:
             time.sleep(sleep_timeout)
-            message = self.message_queue_client.receive_message(timeout)
+            body, message = self.message_queue_client.receive_message(timeout)
             if message is None:
                 continue
-            body, message = base64.b64decode(message.content).decode()
             self.process_message(body, process_func)
             self.message_queue_client.delete_message(message)
 
